!+ K of surface variables
!
MODULE MOD_SURFK
  !
  !    This software was developed within the context of 
  !    the EUMETSAT Satellite Application Facility on 
  !    Numerical Weather Prediction (NWP SAF), under the 
  !    Cooperation Agreement dated 25 November 1998, between 
  !    EUMETSAT and the Met Office, UK, by one or more partners 
  !    within the NWP SAF. The partners in the NWP SAF are 
  !    the Met Office, ECMWF, KNMI and MeteoFrance.
  ! 
  !    Copyright 2002, EUMETSAT, All Rights Reserved.
  !
  ! Description:
  ! K of surface variables
  !
  ! Owner:
  ! SAF NWP
  !
  ! History:
  ! Version      Date        Comment
  ! 1            01/05/2000  Original code.
  !
  ! Code description:
  ! Language:              Fortran 90.
  ! Software Standards:    "European Standards for Writing and Documenting
  !                              Exchangeable Fortran 90 code".

  ! Module used
  USE MOD_CPARAM, ONLY : &
  ! Imported Paramters:
  jppf  ,&        ! Max no. of profs * chans used
  jpchpf        ! Max no. of profs * chans used

  IMPLICIT NONE

  ! Module arguments:

  ! Global arrays:
  INTEGER :: nlevsf(jppf)     ! Index of nearest std press level at/below 
                              ! surface.
  INTEGER :: nstype(jpchpf)   ! Surface type index; 1=sea, 0=land 2 =ice
  REAL    :: fracps(jpchpf)   ! Fraction of std press level interval by which 
                              ! surface is above level NLEVSF.
  REAL    :: surfw(jpchpf)    ! Surface windspeed m/s
  REAL    :: surfd(jpchpf)    ! Surface winddirection deg

  ! End of module arguments


!-----End of header-----------------------------------------------------

END MODULE MOD_SURFK

